Constrained Layout Example
===============================================================================

:download:`constrained.enaml <../../../examples/constrained/constrained.enaml>`

.. literalinclude:: ../../../examples/constrained/constrained.enaml
    :language: python

::

 $ enaml-run constrained.enaml

.. image:: images/constrained0.png

.. note:: The "Change Mode" button has a weak constraint to the mid-line.

.. image:: images/constrained1.png
